from PIL import Image
import numpy as np
from matplotlib import pyplot as plt

def ouvrir_image(nom_fichier: str) -> np.ndarray:
    '''
    Prend en argument une chaîne de caractère correspondant à un nom de
    fichier image au format PNG (le chemin absolu du fichier) et renvoie
    un tableau numpy correspondant à l'image, contenant des entiers non
    signés sur 8 bits.

    Exemple : im = ouvrir_image("/home/modélisation/martin_pecheur.png")
    '''
    return np.array(Image.open(nom_fichier))

def sauvegarder_image(image: np.ndarray, nom_fichier: str) -> None:
    '''
    Prend en argument une image au format tableau numpy et une chaîne de
    caractères correspondant à un nom de fichier (le chemin absolu) et
    enregistre l'image au chemin donné.

    La fonction crée un nouveau fichier s'il n'existe pas ou écrase le
    fichier portant le même nom s'il existe déjà.

    Exemple : sauvegarder_image(im, "/home/tests/essai1.png")
    '''
    Image.fromarray(image).save(nom_fichier)

def afficher_images(*args: np.ndarray) -> None:
    '''
    Prend un nombre quelconque d'arguments correspondant à des images au
    format tableau numpy et les affiche côte à côte dans une nouvelle
    fenêtre via matplotlib.

    Exemple : affichier_images(im1, im2, im3)
    '''
    n = len(args)
    for i in range(n):
        plt.subplot(1, n, i + 1)
        if len(args[i].shape) == 2:
            plt.imshow(args[i], cmap = "gray", vmin=0, vmax=255)
        else:
            plt.imshow(args[i], vmin=0, vmax=255)
    plt.show()